from wafer.settings import *

TEMPLATES[0]['OPTIONS']['context_processors'] += (
    'debconf.context_processors.expose_time_zone',
    'debconf.context_processors.expose_debconf_online',
)

BAKERY_VIEWS += (
    'debconf.views.RobotsView',
    'debconf.views.IndexView',
    'debconf.views.DebConfScheduleView',
    'debconf.views.StatisticsView',
    'debconf.views.ContentStatisticsView',
    'register.views.statistics.StatisticsView',
    'volunteers.views.VolunteerStatisticsView',
)

DEBCONF_ONLINE = False



from django.conf.urls import url

from debconf.views import (
    ContentStatisticsView, DCScheduleArrived, DebConfScheduleView, IndexView,
    RobotsView, StatisticsView,
)

urlpatterns = [
    url(r'^attendees/admin/export/arrived/$', DCScheduleArrived.as_view()),
    url(r'^schedule/$', DebConfScheduleView.as_view(),
        name='wafer_full_schedule'),
    url(r'^robots.txt$', RobotsView.as_view()),
    url(r'^$', IndexView.as_view()),
    url(r'^statistics/$', StatisticsView.as_view()),
    url(r'^talks/statistics/$', ContentStatisticsView.as_view(),
        name='content-statistics'),
]



from django.conf import settings

def expose_time_zone(request):
    return {'TIME_ZONE': settings.TIME_ZONE}


def expose_debconf_online(request):
    return {'DEBCONF_ONLINE': settings.DEBCONF_ONLINE}
